# Todo

- tempo label do lado to fixar label ao lado dos cases
- +- label ao lado do tab para habilitar e desabilitar
- +- no mesmo simbolo se possível

- pasta user para adicionar problemas do usuário
- paleta embaixo abrindo floating com textos pendurados em functors
- opção de mostrar quantos testes passaram no principal
- opção de rodar os testes no computador do aluno
- for each folder tko test folder --compact

- 3 modos de fazer a tarefa
  - sozinho
  - ajuda (grupo, monitor, colega, IA, internet)
  - guiado (aula, vídeo, tutorial)
- 3 níveis de compreensão do conteúdo
  - superficial
  - intermediário
  - profundo
- 3 níveis de dificuldade
  - fácil
  - médio
  - difícil
